aboutsummaryrefslogtreecommitdiffstats
path: root/packet-rtp.c
diff options
context:
space:
mode:
Diffstat (limited to 'packet-rtp.c')
-rw-r--r--packet-rtp.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/packet-rtp.c b/packet-rtp.c
index 557f9951b5..cdd3d5f368 100644
--- a/packet-rtp.c
+++ b/packet-rtp.c
@@ -6,7 +6,7 @@
* Copyright 2000, Philips Electronics N.V.
* Written by Andreas Sikkema <andreas.sikkema@philips.com>
*
- * $Id: packet-rtp.c,v 1.29 2001/12/03 03:59:39 guy Exp $
+ * $Id: packet-rtp.c,v 1.30 2001/12/03 08:47:27 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -785,9 +785,9 @@ proto_reg_handoff_rtp(void)
data_handle = find_dissector("data");
/*
* Register this dissector as one that can be assigned to a
* UDP conversation.
*/
rtp_handle = find_dissector("rtp");
- conv_dissector_add("udp", rtp_handle);
+ dissector_add_handle("udp.port", rtp_handle);
}
@@ -785,9 +785,9 @@ proto_reg_handoff_rtp(void)
data_handle = find_dissector("data");
/*
- * Register this dissector as one that can be assigned to a
- * UDP conversation.
+ * Register this dissector as one that can be selected by a
+ * UDP port number.
*/
rtp_handle = find_dissector("rtp");